#!/usr/bin/perl
# This script provides temporary capture and replay of loginfo stdin, so that
# we can run multiple processing scripts.
# robbat2@gentoo.org, 2008/12/02
#
# Example use (remote the \, it must be on a single line for the loginfo file).
# ALL ( $CVSROOT/CVSROOT/cvslogholder.pl --capture %c %r %p %{sVv} ; \
#		$CVSROOT/CVSROOT/cvslogholder.pl --display %c %r %p %{sVv} | script1 ; \
#		$CVSROOT/CVSROOT/cvslogholder.pl --display %c %r %p %{sVv} | script2 ; \
#		$CVSROOT/CVSROOT/cvslogholder.pl --cleanup %c %r %p %{sVv} )
use strict;
use warnings;
use Digest::SHA1 qw(sha1_hex);
use Getopt::Long;

my $LOGDIR = '/mnt/cvstmpdir/';
my $USER = $ENV{'USER'};

my $CMD_CAPTURE = 0;
my $CMD_DISPLAY = 0;
my $CMD_CLEANUP = 0;
my $CMD_HELP = 0;

my $result = GetOptions( 
	"capture" => \$CMD_CAPTURE, 
	"display" => \$CMD_DISPLAY,
	"cleanup" => \$CMD_CLEANUP,
);

unless($CMD_CAPTURE + $CMD_DISPLAY + $CMD_CLEANUP == 1 and @ARGV > 0) {
	print STDERR "You must specify exactly one mode and arguments.\n";
	exit(1);
}

my $args = (join(' ', (map { sprintf( "'%s'",$_); } @ARGV)));
#printf "args: %s\n", $args;
my $argchecksum = sha1_hex($args);
#printf "argchecksum: %s\n", $argchecksum;

my $basename = sprintf("%s/cvslog-%s-%s",$LOGDIR, $USER, $argchecksum);
#printf "basename: $basename";

my $argfile = $basename.".args";
my $logfile = $basename.".log";

if($CMD_CAPTURE == 1) {
	if(-f $argfile) {
		print STDERR "argfile $argfile already exists. Serious error!\n";
		exit(2);
	}
	
	if(-f $logfile) {
		print STDERR "logfile $logfile already exists. Serious error!\n";
		exit(2);
	}
	
	open ARGFILE,">", $argfile or die "Unable to create $argfile.";
	print ARGFILE join('',map { sprintf("%s\n", $_); } @ARGV);
	close ARGFILE;
	
	
	open LOGFILE,">", $logfile or die "Unable to create $logfile.";
	while(<STDIN>) {
		print LOGFILE $_;
	}
	close LOGFILE;
} elsif($CMD_DISPLAY) {
	open LOGFILE,"<", $logfile or die "Unable to find $logfile";
	while(<LOGFILE>) {
		print $_;
	}
	close LOGFILE;
} elsif($CMD_CLEANUP) {
	unlink $logfile;
	unlink $argfile;
}
